import pytest


class TestSimpleSession:
    def setup_test(self):
        # self.session = web.SimpleSession("youtube", root_url=youtube_home_url, headers=headers)
        pass

    def test_get_form_inputs(self):
        pass

    def test_enter_search_form(self):
        pass
